API/Dashboard
=============

.. automodule:: chancy.plugins.api
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: chancy.plugins.api.plugin
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: chancy.plugins.api.core
   :members:
   :undoc-members:
   :show-inheritance:
